@@ -2,7 +2,7 @@
 #'
 #' @description Electronic LEngth Frequency ANalysis for estimating growth parameter.
 #'
-#' @param x a list consisting of following parameters:
+#' @param lfq a list consisting of following parameters:
 #' \itemize{
 #'   \item \strong{midLengths} midpoints of the length classes,
 #'   \item \strong{dates} dates of sampling times (class Date),
@@ -56,7 +56,7 @@
 #'
 #' # 'cross' method (used in FiSAT)
 #' fit1 <- ELEFAN(
-#'    x = alba, method = "cross",
+#'    lfq = alba, method = "cross",
 #'    Linf_range = seq(from = 10, to = 20, length.out = 10),
 #'    K_range = exp(seq(from = log(0.1), to = log(2), length.out = 20)),
 #'    cross.date = alba$dates[3], cross.midLength = alba$midLengths[4],
@@ -67,7 +67,7 @@
 #'
 #' # 'cross' method (bin with maximum score crossed)
 #' fit2 <- ELEFAN(
-#'    x = alba, method = "cross",
+#'    lfq = alba, method = "cross",
 #'    Linf_range = seq(from = 10, to = 20, length.out = 20),
 #'    K_range = exp(seq(from = log(0.1), to = log(2), length.out = 20)),
 #'    cross.max = TRUE,
@@ -79,7 +79,7 @@
 #'
 #' # 'optimise' method (default)
 #' fit3 <- ELEFAN(
-#'    x = alba, method = "optimise",
+#'    lfq = alba, method = "optimise",
 #'    Linf_range = seq(from = 10, to = 20, length.out = 10),
 #'    K_range = exp(seq(from = log(0.1), to = log(2), length.out = 20)),
 #'    contour = TRUE
@@ -92,7 +92,7 @@
 #'
 #' # 'cross' method
 #' fit4 <- ELEFAN(
-#'    x = alba, method = "cross",
+#'    lfq = alba, method = "cross",
 #'    Linf_fix = 10,
 #'    K_range = round(exp(seq(from = log(0.1), to = log(2), length.out = 50)),2),
 #'    cross.date = alba$dates[3], cross.midLength = alba$midLengths[4]
@@ -194,20 +194,18 @@
 #'
 #' @export
 
-ELEFAN <- function(
-  x, Linf_fix = NA, Linf_range = NA,
-  K_range = exp(seq(log(0.1), log(10), length.out=100)),
-  C = 0, ts = 0,
-  MA = 5, addl.sqrt = FALSE,
-  agemax = NULL, flagging.out = TRUE, method = "optimise",
-  cross.date = NULL, cross.midLength = NULL, cross.max = FALSE,
-  hide.progressbar = FALSE,
-  plot = FALSE, contour = FALSE,
-  add.values = TRUE, rsa.colors = terrain.colors(20),
-  plot_title = TRUE)
-{
+ELEFAN <- function(lfq, Linf_fix = NA, Linf_range = NA,
+                   K_range = exp(seq(log(0.1), log(10), length.out=100)),
+                   C = 0, ts = 0,
+                   MA = 5, addl.sqrt = FALSE,
+                   agemax = NULL, flagging.out = TRUE, method = "optimise",
+                   cross.date = NULL, cross.midLength = NULL, cross.max = FALSE,
+                   hide.progressbar = FALSE,
+                   plot = FALSE, contour = FALSE,
+                   add.values = TRUE, rsa.colors = terrain.colors(20),
+                   plot_title = TRUE){
 
-  res <- x
+  res <- lfq
   classes <- res$midLengths
   catch <- res$catch
   dates <- res$dates
@@ -417,4 +415,3 @@ ELEFAN <- function(
   }
   return(res)
 }
-
