@@ -3,7 +3,7 @@
 #' @description Electronic LEngth Frequency ANalysis with genetic algorithm
 #' used for estimating growth parameters.
 #'
-#' @param x a list consisting of following parameters:
+#' @param lfq a list consisting of following parameters:
 #' \itemize{
 #'   \item \strong{midLengths} midpoints of the length classes,
 #'   \item \strong{dates} dates of sampling times (class Date),
@@ -162,164 +162,158 @@
 #'
 #' @export
 
-ELEFAN_GA <- function(
-  x,
-  seasonalised = FALSE,
-  low_par = NULL,
-  up_par = NULL,
-  popSize = 50,
-  maxiter = 100,
-  run = maxiter,
-  parallel = FALSE,
-  pmutation = 0.1,
-  pcrossover = 0.8,
-  elitism = base::max(1, round(popSize*0.05)),
-  MA = 5,
-  addl.sqrt = FALSE,
-  agemax = NULL,
-  flagging.out = TRUE,
-  seed = NULL,
-  monitor = FALSE,
-  plot = FALSE,
-  plot.score = TRUE,
-  ...
-){
+ELEFAN_GA <- function(lfq,
+                      seasonalised = FALSE,
+                      low_par = NULL,
+                      up_par = NULL,
+                      popSize = 50,
+                      maxiter = 100,
+                      run = maxiter,
+                      parallel = FALSE,
+                      pmutation = 0.1,
+                      pcrossover = 0.8,
+                      elitism = base::max(1, round(popSize*0.05)),
+                      MA = 5,
+                      addl.sqrt = FALSE,
+                      agemax = NULL,
+                      flagging.out = TRUE,
+                      seed = NULL,
+                      monitor = FALSE,
+                      plot = FALSE,
+                      plot.score = TRUE, ...){
 
-  lfq <- x
-  classes <- lfq$midLengths
-  n_classes <- length(classes)
-  Linf_est <- classes[n_classes]
+    classes <- lfq$midLengths
+    n_classes <- length(classes)
+    Linf_est <- classes[n_classes]
 
-  # lower parameter bounds
-  low_par_ALL <- list(Linf = Linf_est * 0.5,
-                      K = 0.01,
-                      t_anchor = 0,
-                      C = 0,
-                      ts = 0)
-  low_Linf <- ifelse("Linf" %in% names(low_par),
-                     get("Linf", low_par),
-                     get("Linf", low_par_ALL))
-  low_K <- ifelse("K" %in% names(low_par),
-                  get("K", low_par),
-                  get("K", low_par_ALL))
-  low_tanc <- ifelse("t_anchor" %in% names(low_par),
-                     get("t_anchor", low_par),
-                     get("t_anchor", low_par_ALL))
-  low_C <- ifelse("C" %in% names(low_par),
-                  get("C", low_par),
-                  get("C", low_par_ALL))
-  low_ts <- ifelse("ts" %in% names(low_par),
-                   get("ts", low_par),
-                   get("ts", low_par_ALL))
+    # lower parameter bounds
+    low_par_ALL <- list(Linf = Linf_est * 0.5,
+                        K = 0.01,
+                        t_anchor = 0,
+                        C = 0,
+                        ts = 0)
+    low_Linf <- ifelse("Linf" %in% names(low_par),
+                       get("Linf", low_par),
+                       get("Linf", low_par_ALL))
+    low_K <- ifelse("K" %in% names(low_par),
+                    get("K", low_par),
+                    get("K", low_par_ALL))
+    low_tanc <- ifelse("t_anchor" %in% names(low_par),
+                       get("t_anchor", low_par),
+                       get("t_anchor", low_par_ALL))
+    low_C <- ifelse("C" %in% names(low_par),
+                    get("C", low_par),
+                    get("C", low_par_ALL))
+    low_ts <- ifelse("ts" %in% names(low_par),
+                     get("ts", low_par),
+                     get("ts", low_par_ALL))
 
-  # upper parameter bounds
-  up_par_ALL <- list(Linf = Linf_est * 1.5,
-                     K = 1,
-                     t_anchor = 1,
-                     C = 1,
-                     ts = 1)
-  up_Linf <- ifelse("Linf" %in% names(up_par),
-                    get("Linf", up_par),
-                    get("Linf", up_par_ALL))
-  up_K <- ifelse("K" %in% names(up_par),
-                 get("K", up_par),
-                 get("K", up_par_ALL))
-  up_tanc <- ifelse("t_anchor" %in% names(up_par),
-                    get("t_anchor", up_par),
-                    get("t_anchor", up_par_ALL))
-  up_C <- ifelse("C" %in% names(up_par),
-                 get("C", up_par),
-                 get("C", up_par_ALL))
-  up_ts <- ifelse("ts" %in% names(up_par),
-                  get("ts", up_par),
-                  get("ts", up_par_ALL))
+    # upper parameter bounds
+    up_par_ALL <- list(Linf = Linf_est * 1.5,
+                       K = 1,
+                       t_anchor = 1,
+                       C = 1,
+                       ts = 1)
+    up_Linf <- ifelse("Linf" %in% names(up_par),
+                      get("Linf", up_par),
+                      get("Linf", up_par_ALL))
+    up_K <- ifelse("K" %in% names(up_par),
+                   get("K", up_par),
+                   get("K", up_par_ALL))
+    up_tanc <- ifelse("t_anchor" %in% names(up_par),
+                      get("t_anchor", up_par),
+                      get("t_anchor", up_par_ALL))
+    up_C <- ifelse("C" %in% names(up_par),
+                   get("C", up_par),
+                   get("C", up_par_ALL))
+    up_ts <- ifelse("ts" %in% names(up_par),
+                    get("ts", up_par),
+                    get("ts", up_par_ALL))
 
-  # ELEFAN 0
-  lfq <- lfqRestructure(lfq, MA = MA, addl.sqrt = addl.sqrt)
+    # ELEFAN 0
+    lfq <- lfqRestructure(lfq, MA = MA, addl.sqrt = addl.sqrt)
 
-  # seasonalised fitness function
-  sofun <- function(lfq, par, agemax, flagging.out){
-    Lt <- lfqFitCurves(lfq,
-                       par=list(Linf=par[1], K=par[2], t_anchor=par[3], C=par[4], ts=par[5]),
-                       agemax = agemax, flagging.out = flagging.out)
-    return(Lt$fESP)
-  }
-  # non-seasonalised fitness function
-  fun <- function(lfq, par, agemax, flagging.out){
-    Lt <- lfqFitCurves(lfq,
-                       par=list(Linf=par[1], K=par[2], t_anchor=par[3], C = 0, ts = 0),
-                       agemax = agemax, flagging.out = flagging.out)
-    return(Lt$fESP)
-  }
+    # seasonalised fitness function
+    sofun <- function(lfq, par, agemax, flagging.out){
+        Lt <- lfqFitCurves(lfq,
+                           par=list(Linf=par[1], K=par[2], t_anchor=par[3], C=par[4], ts=par[5]),
+                           agemax = agemax, flagging.out = flagging.out)
+        return(Lt$fESP)
+    }
+    # non-seasonalised fitness function
+    fun <- function(lfq, par, agemax, flagging.out){
+        Lt <- lfqFitCurves(lfq,
+                           par=list(Linf=par[1], K=par[2], t_anchor=par[3], C = 0, ts = 0),
+                           agemax = agemax, flagging.out = flagging.out)
+        return(Lt$fESP)
+    }
 
 
-  # Genetic algorithm
-  if(seasonalised){
-    min = c(low_Linf, low_K, low_tanc, low_C, low_ts)
-    max = c(up_Linf, up_K, up_tanc, up_C, up_ts)
-    writeLines("Genetic algorithm is running. This might take some time.")
-    flush.console()
-    fit <- GA::ga(
-      type = "real-valued",
-      fitness = sofun, lfq=lfq,
-      min = min,
-      max = max,
-      agemax = agemax,
-      flagging.out = flagging.out,
-      popSize = popSize, maxiter = maxiter, run = run, parallel = parallel,
-      pmutation = pmutation, pcrossover = pcrossover, elitism = elitism,
-      seed = seed, monitor = monitor,
-      ...
-    )
-    pars <- as.list(fit@solution[1,])
-    names(pars) <- c("Linf", "K", "t_anchor", "C", "ts")
-  }else{
-    min = c(low_Linf, low_K, low_tanc)
-    max = c(up_Linf, up_K, up_tanc)
-    writeLines("Genetic algorithm is running. This might take some time.")
-    flush.console()
-    fit <- GA::ga(
-      type = "real-valued",
-      fitness = fun,
-      lfq=lfq,
-      min = min,
-      max = max,
-      agemax = agemax,
-      flagging.out = flagging.out,
-      popSize = popSize, maxiter = maxiter, run = run, parallel = parallel,
-      pmutation = pmutation, pcrossover = pcrossover, elitism = elitism,
-      seed = seed,
-      monitor = monitor,
-      ...
-    )
-    pars <- as.list(fit@solution[1,])
-    names(pars) <- c("Linf", "K", "t_anchor")
-  }
+    # Genetic algorithm
+    if(seasonalised){
+        min = c(low_Linf, low_K, low_tanc, low_C, low_ts)
+        max = c(up_Linf, up_K, up_tanc, up_C, up_ts)
+        writeLines("Genetic algorithm is running. This might take some time.")
+        flush.console()
+        fit <- GA::ga(type = "real-valued",
+                       fitness = sofun, lfq=lfq,
+                       lower = min,
+                       upper = max,
+                       agemax = agemax,
+                       flagging.out = flagging.out,
+                       popSize = popSize, maxiter = maxiter, run = run, parallel = parallel,
+                       pmutation = pmutation, pcrossover = pcrossover, elitism = elitism,
+                       seed = seed, monitor = monitor,
+                       ...)
+        pars <- as.list(fit@solution[1,])
+        names(pars) <- c("Linf", "K", "t_anchor", "C", "ts")
+    }else{
+        min = c(low_Linf, low_K, low_tanc)
+        max = c(up_Linf, up_K, up_tanc)
+        writeLines("Genetic algorithm is running. This might take some time.")
+        flush.console()
+        fit <- GA::ga(
+                       type = "real-valued",
+                       fitness = fun,
+                       lfq=lfq,
+                       lower = min,
+                       upper = max,
+                       agemax = agemax,
+                       flagging.out = flagging.out,
+                       popSize = popSize, maxiter = maxiter, run = run, parallel = parallel,
+                       pmutation = pmutation, pcrossover = pcrossover, elitism = elitism,
+                       seed = seed,
+                       monitor = monitor,
+                       ...
+                   )
+        pars <- as.list(fit@solution[1,])
+        names(pars) <- c("Linf", "K", "t_anchor")
+    }
 
-  # Fitness graph
-  if(plot.score){
-    GA::plot(fit)
-  }
+    # Fitness graph
+    if(plot.score){
+        GA::plot(fit)
+    }
 
-  final_res <- lfqFitCurves(
-    lfq = lfq, par=pars,
-    flagging.out = flagging.out,
-    agemax = agemax)
+    final_res <- lfqFitCurves(
+        lfq = lfq, par=pars,
+        flagging.out = flagging.out,
+        agemax = agemax)
 
-  # growth performance index
-  phiL <- log10(pars$K) + 2 * log10(pars$Linf)
-  pars$phiL <- phiL
+    # growth performance index
+    phiL <- log10(pars$K) + 2 * log10(pars$Linf)
+    pars$phiL <- phiL
 
-  # Results
-  lfq$ncohort <- final_res$ncohort
-  lfq$agemax <- final_res$agemax
-  lfq$par <- pars
-  lfq$fESP <- fit@fitnessValue
-  lfq$Rn_max <- fit@fitnessValue
+    # Results
+    lfq$ncohort <- final_res$ncohort
+    lfq$agemax <- final_res$agemax
+    lfq$par <- pars
+    lfq$fESP <- fit@fitnessValue
+    lfq$Rn_max <- fit@fitnessValue
 
-  if(plot){
-    plot(lfq, Fname = "rcounts")
-    Lt <- lfqFitCurves(lfq, par = lfq$pars, draw=TRUE)
-  }
-  return(lfq)
+    if(plot){
+        plot(lfq, Fname = "rcounts")
+        Lt <- lfqFitCurves(lfq, par = lfq$pars, draw=TRUE)
+    }
+    return(lfq)
 }
