@@ -51,11 +51,11 @@ lfqModify <- function(lfq, par = NULL,
                       minDate = NA,
                       maxDate = NA,
                       years = NA,
-                      Lmin = NA,                      
+                      Lmin = NA,
                       Lmax = NA,
                       lfq2 = NA){
 
-    if(class(lfq) != "lfq") stop("Your lfq data set has to have class 'lfq'!")
+    if(!inherits(lfq,"lfq")) stop("Your lfq data set has to have class 'lfq'!")
     dates <- lfq$dates
     midLengths <- lfq$midLengths
     catch <- lfq$catch
@@ -79,13 +79,13 @@ lfqModify <- function(lfq, par = NULL,
     ## select beyond certain date
     if(!is.na(minDate)){
         catch <- lfq$catch[,which(dates >= minDate)]
-        dates <- lfq$dates[which(dates >= minDate)]        
+        dates <- lfq$dates[which(dates >= minDate)]
     }
-    
+
     ## select before certain date
     if(!is.na(maxDate)){
         catch <- catch[,which(dates <= maxDate)]
-        dates <- dates[which(dates <= maxDate)]        
+        dates <- dates[which(dates <= maxDate)]
     }
 
     ## select certain years
@@ -109,8 +109,8 @@ lfqModify <- function(lfq, par = NULL,
 
     ## merge two lfq data sets (ADD weighing factor)
     if(!any(is.na(lfq2))){
-        if(class(lfq2) != "lfq") stop("Your lfq2 data set has to have class 'lfq'!")
-        
+        if(!inherits(lfq2,"lfq")) stop("Your lfq2 data set has to have class 'lfq'!")
+
         ## extract variables
         dates2 <- lfq2$dates
         midLengths2 <- lfq2$midLengths
@@ -119,7 +119,7 @@ lfqModify <- function(lfq, par = NULL,
         ## error messages
         if(diff(midLengths)[1] != diff(midLengths2)[1]) stop("The bin sizes do not fit eachother")
         if(any(!dates2 %in% dates)) warning("At least one sampling date of lfq2 does not match with the dates \nin lfq, not matching dates will be added!")
-        
+
         mergi <- merge(data.frame(dates=dates,x=dates),
                        data.frame(dates=dates2,y=dates2),
                        by="dates",all=TRUE)
@@ -139,7 +139,7 @@ lfqModify <- function(lfq, par = NULL,
         mat <- matrix(0, nrow=length(ind), ncol=ncol(catch))
         catch <- rbind(mat,catch)
 
-        
+
         ## both catch matrices should have same sampling dates
         designMat <- matrix(0, ncol=length(mergi$dates), nrow=length(mergi2$midLengths))
         temp <- designMat
@@ -152,7 +152,7 @@ lfqModify <- function(lfq, par = NULL,
         temp <- designMat
         ind = 1
         for(i in which(!is.na(mergi$y))){
-                temp[,i] <- catch2[,ind]
+            temp[,i] <- catch2[,ind]
             ind <- ind + 1
         }
         catch2 <- temp
@@ -162,7 +162,7 @@ lfqModify <- function(lfq, par = NULL,
             temp1 <- data.frame(midLengths = mergi2$midLengths,
                                 catch1 = catch[,i])
             temp2 <- data.frame(midLengths = mergi2$midLengths,
-                                catch2 = catch2[,i])            
+                                catch2 = catch2[,i])
             temp3 <- merge(temp1, temp2, by="midLengths", all=TRUE)
             designMat[,i] <- rowSums(temp3[,c(2,3)])
         }
@@ -171,9 +171,9 @@ lfqModify <- function(lfq, par = NULL,
         dates <- mergi$dates
         midLengths <- mergi2$midLengths
         catch <- designMat
-        
+
     }
-    
+
 
     if(!is.na(bin_size)){
 
@@ -184,7 +184,7 @@ lfqModify <- function(lfq, par = NULL,
         bin.breaks <- seq(0, max(midLengths) + bin_size, by=bin_size)
         midLengthsNEW <- bin.breaks + bin_size/2
         listi <- vector("list",length(unique(dates)))
-        LF_dat <- data.frame(bin = bin.breaks)    
+        LF_dat <- data.frame(bin = bin.breaks)
         for(i in 1:length(unique(dates))){
             sampli <- unique(dates)[i]
             lengthi <- as.numeric(midLengths)
@@ -193,7 +193,7 @@ lfqModify <- function(lfq, par = NULL,
                 freqi <- as.numeric(catch[,dates == sampli])
             }else{
                 freqi <- as.numeric(catch[dates == sampli])
-            }            
+            }
 
             bin.breaks2 <- rep(NA, length(bin.breaks))
             for(ii in 1:length(bin.breaks)){
@@ -220,15 +220,15 @@ lfqModify <- function(lfq, par = NULL,
             lowRow <- 0
             resi <- TRUE
             while(resi == TRUE){
-              lowRow <- lowRow + 1
-              resi <- rowSums(catch, na.rm = TRUE)[lowRow] == 0
+                lowRow <- lowRow + 1
+                resi <- rowSums(catch, na.rm = TRUE)[lowRow] == 0
             }
 
             upRow <- nrow(catch)
             resi <- TRUE
             while(resi == TRUE){
-              resi <- rowSums(catch, na.rm = TRUE)[upRow] == 0
-              upRow <- upRow - 1
+                resi <- rowSums(catch, na.rm = TRUE)[upRow] == 0
+                upRow <- upRow - 1
             }
             upRow <- upRow + 1
 
@@ -238,14 +238,15 @@ lfqModify <- function(lfq, par = NULL,
         }
 
         ## correct if catch was numeric already
-        if(class(lfq$catch) == "numeric"){
+        if(inherits(lfq$catch,"numeric")){
             catch <- as.numeric(catch)
         }
 
-      }
-      if(vectorise_catch & !is.matrix(catch)){
-        stop(paste0("Catch is ", class(catch), ". To vectorise catch, it has to be a matrix."))
-      }
+    }
+    ismat <- inherits(catch,"matrix")
+    if(vectorise_catch & !ismat){
+        stop(paste0("Catch is not of class matrix. To vectorise catch, it has to be a matrix."))
+    }
     if(vectorise_catch) aggregate = "year"
     if(!is.na(aggregate) & is.matrix(catch)){
         if(aggregate == "year"){
@@ -255,28 +256,28 @@ lfqModify <- function(lfq, par = NULL,
             c_list <- lapply(as.list(c_sum), c)
             c_dat <- as.data.frame(c_list)
 
-              if(any(c_dat != 0)){
-                  # get rid of 0 bins at both ends
-                  lowRow <- 0
-                  resi <- TRUE
-                  while(resi == TRUE){
+            if(any(c_dat != 0)){
+                # get rid of 0 bins at both ends
+                lowRow <- 0
+                resi <- TRUE
+                while(resi == TRUE){
                     lowRow <- lowRow + 1
                     resi <- rowSums(c_dat, na.rm = TRUE)[lowRow] == 0
-                  }
+                }
 
-                  upRow <- nrow(c_dat)
-                  resi <- TRUE
-                  while(resi == TRUE){
+                upRow <- nrow(c_dat)
+                resi <- TRUE
+                while(resi == TRUE){
                     resi <- rowSums(c_dat, na.rm = TRUE)[upRow] == 0
                     upRow <- upRow - 1
-                  }
-                  upRow <- upRow + 1
+                }
+                upRow <- upRow + 1
 
-                  catch <- c_dat[lowRow:upRow,]
-                  midLengths <- midLengths[lowRow:upRow]
-              }else{
-                  catch <- c_dat
-              }
+                catch <- c_dat[lowRow:upRow,]
+                midLengths <- midLengths[lowRow:upRow]
+            }else{
+                catch <- c_dat
+            }
 
             # override old dates
             dates <- unique(as.Date(paste0(format(dates,"%Y"),"-01-01")))
@@ -302,28 +303,28 @@ lfqModify <- function(lfq, par = NULL,
             c_list <- lapply(as.list(c_sum), c)
             c_dat <- as.data.frame(c_list)
 
-              if(any(c_dat != 0)){
-                  # get rid of 0 bins at both ends
-                  lowRow <- 0
-                  resi <- TRUE
-                  while(resi == TRUE){
-                    lowRow <- lowRow + 1
-                    resi <- rowSums(c_dat, na.rm = TRUE)[lowRow] == 0
-                  }
+            if(any(c_dat != 0)){
+                # get rid of 0 bins at both ends
+                lowRow <- 0
+                resi <- TRUE
+                while(resi == TRUE){
+            lowRow <- lowRow + 1
+            resi <- rowSums(c_dat, na.rm = TRUE)[lowRow] == 0
+        }
 
-                  upRow <- nrow(c_dat)
-                  resi <- TRUE
-                  while(resi == TRUE){
-                    resi <- rowSums(c_dat, na.rm = TRUE)[upRow] == 0
-                    upRow <- upRow - 1
-                  }
-                  upRow <- upRow + 1
+                upRow <- nrow(c_dat)
+                resi <- TRUE
+                while(resi == TRUE){
+            resi <- rowSums(c_dat, na.rm = TRUE)[upRow] == 0
+            upRow <- upRow - 1
+        }
+                upRow <- upRow + 1
 
-                  catch <- c_dat[lowRow:upRow,]
-                  midLengths <- midLengths[lowRow:upRow]
-              }else{
-                  catch <- c_dat
-              }
+                catch <- c_dat[lowRow:upRow,]
+                midLengths <- midLengths[lowRow:upRow]
+            }else{
+                catch <- c_dat
+            }
 
             # override old dates
             dates <- unique(dateFac)
@@ -334,28 +335,28 @@ lfqModify <- function(lfq, par = NULL,
             c_list <- lapply(as.list(c_sum), c)
             c_dat <- as.data.frame(c_list)
 
-              if(any(c_dat != 0)){
-                  # get rid of 0 bins at both ends
-                  lowRow <- 0
-                  resi <- TRUE
-                  while(resi == TRUE){
-                    lowRow <- lowRow + 1
-                    resi <- rowSums(c_dat, na.rm = TRUE)[lowRow] == 0
-                  }
+            if(any(c_dat != 0)){
+                # get rid of 0 bins at both ends
+                lowRow <- 0
+                resi <- TRUE
+                while(resi == TRUE){
+            lowRow <- lowRow + 1
+            resi <- rowSums(c_dat, na.rm = TRUE)[lowRow] == 0
+        }
 
-                  upRow <- nrow(c_dat)
-                  resi <- TRUE
-                  while(resi == TRUE){
-                    resi <- rowSums(c_dat, na.rm = TRUE)[upRow] == 0
-                    upRow <- upRow - 1
-                  }
-                  upRow <- upRow + 1
+                upRow <- nrow(c_dat)
+                resi <- TRUE
+                while(resi == TRUE){
+            resi <- rowSums(c_dat, na.rm = TRUE)[upRow] == 0
+            upRow <- upRow - 1
+        }
+                upRow <- upRow + 1
 
-                  catch <- c_dat[lowRow:upRow,]
-                  midLengths <- midLengths[lowRow:upRow]
-              }else{
-                  catch <- c_dat
-              }
+                catch <- c_dat[lowRow:upRow,]
+                midLengths <- midLengths[lowRow:upRow]
+            }else{
+                catch <- c_dat
+            }
 
             # override old dates
             dates <- unique(as.Date(paste0(format(dates,"%Y-%m"),"-15")))
@@ -364,40 +365,40 @@ lfqModify <- function(lfq, par = NULL,
         }
     }
 
-      # plus group
-      if(isTRUE(plus_group) | is.numeric(plus_group) | plus_group == "Linf"){
+    # plus group
+    if(isTRUE(plus_group) | is.numeric(plus_group) | plus_group == "Linf"){
         if(isTRUE(plus_group)){
-          if(is.vector(catch)){
-            print(data.frame(midLengths = midLengths, frequency = catch))
-          }else if(length(unique(format(lfq$dates, "%Y"))) == 1){
-            print(data.frame(midLengths = midLengths, frequency = rowSums(catch)))
-          }else{
-            # sum numbers per year
-            c_sum <- by(t(catch),format(dates,"%Y"), FUN = colSums)
+            if(is.vector(catch)){
+                print(data.frame(midLengths = midLengths, frequency = catch))
+            }else if(length(unique(format(lfq$dates, "%Y"))) == 1){
+                print(data.frame(midLengths = midLengths, frequency = rowSums(catch)))
+            }else{
+                # sum numbers per year
+                c_sum <- by(t(catch),format(dates,"%Y"), FUN = colSums)
 
-            # rearrange in data frame
-            c_list <- lapply(as.list(c_sum), c)
-            c_dat <- as.data.frame(c_list)
+                # rearrange in data frame
+                c_list <- lapply(as.list(c_sum), c)
+                c_dat <- as.data.frame(c_list)
 
-            tmp <- data.frame(midLengths = midLengths)
-            tmp <- cbind(tmp, c_dat)
-            print(tmp)
-          }
+                tmp <- data.frame(midLengths = midLengths)
+                tmp <- cbind(tmp, c_dat)
+                print(tmp)
+            }
 
-          writeLines(paste0("Linf = ",round(linf,2),
-                            ". Check the table above and insert the length of the plus group (Esc to cancel)."))
-          pg = -1
-          while(pg > max(midLengths) | pg < min(midLengths)){
-            pg <- readline(paste0("Enter a length group between ", min(midLengths)," and ",
-                                  max(midLengths),":"))
-            pg = as.numeric(as.character(pg))
-            if(!(pg %in% midLengths)){
-              writeLines(paste0(pg, " is not an element of midLengths (see table)."))
-              pg = -1
-              #pg <- ifelse(grepl("\\D",pg),-1,as.integer(pg))
-              if(is.na(pg)){break}  # breaks when hit enter
+            writeLines(paste0("Linf = ",round(linf,2),
+                              ". Check the table above and insert the length of the plus group (Esc to cancel)."))
+            pg = -1
+            while(pg > max(midLengths) | pg < min(midLengths)){
+                pg <- readline(paste0("Enter a length group between ", min(midLengths)," and ",
+                                      max(midLengths),":"))
+                pg = as.numeric(as.character(pg))
+                if(!(pg %in% midLengths)){
+                    writeLines(paste0(pg, " is not an element of midLengths (see table)."))
+                    pg = -1
+                    #pg <- ifelse(grepl("\\D",pg),-1,as.integer(pg))
+                    if(is.na(pg)){break}  # breaks when hit enter
+                }
             }
-          }
         }else if(is.numeric(plus_group)){
             pg = as.numeric(as.character(plus_group))
         }else if(plus_group == "Linf"){
@@ -410,39 +411,39 @@ lfqModify <- function(lfq, par = NULL,
             }
         }
         if(!(pg %in% midLengths)){
-          stop(paste0(pg, " is not an element of midLengths. Set 'plus_group' TRUE and pick a length class \n or check the vector 'midLengths' in your data."))
+            stop(paste0(pg, " is not an element of midLengths. Set 'plus_group' TRUE and pick a length class \n or check the vector 'midLengths' in your data."))
         }
         midLengths <- midLengths[1:which(midLengths == pg)]
         if(is.vector(catch)){
-          if(which(midLengths == pg) < (length(catch)-1)){
-            addplus <- sum(catch[((which(midLengths == pg)+1):length(catch))])
-          }else if(which(midLengths == pg) == (length(catch)-1)){
-            addplus <- catch[(which(midLengths == pg)+1)]
-          }else if(which(midLengths == pg) == (length(catch))){
-            addplus <- 0
-          }
-          catch <- catch[1:which(midLengths == pg)]
-          catch[which(midLengths == pg)] <-
-            catch[which(midLengths == pg)] + addplus
+            if(which(midLengths == pg) < (length(catch)-1)){
+                addplus <- sum(catch[((which(midLengths == pg)+1):length(catch))])
+            }else if(which(midLengths == pg) == (length(catch)-1)){
+                addplus <- catch[(which(midLengths == pg)+1)]
+            }else if(which(midLengths == pg) == (length(catch))){
+                addplus <- 0
+            }
+            catch <- catch[1:which(midLengths == pg)]
+            catch[which(midLengths == pg)] <-
+                catch[which(midLengths == pg)] + addplus
         }else{
-          if(which(midLengths == pg) < (nrow(catch)-1)){
-            addplus <- colSums(catch[((which(midLengths == pg)+1):nrow(catch)),])
-          }else if(which(midLengths == pg) == (nrow(catch)-1)){
-            addplus <- catch[(which(midLengths == pg)+1),]
-          }else if(which(midLengths == pg) == (nrow(catch))){
-            addplus <- 0
-          }
-          catch <- catch[1:which(midLengths == pg),]
-          catch[which(midLengths == pg),] <-
-            catch[which(midLengths == pg),] + addplus
+            if(which(midLengths == pg) < (nrow(catch)-1)){
+                addplus <- colSums(catch[((which(midLengths == pg)+1):nrow(catch)),])
+            }else if(which(midLengths == pg) == (nrow(catch)-1)){
+                addplus <- catch[(which(midLengths == pg)+1),]
+            }else if(which(midLengths == pg) == (nrow(catch))){
+                addplus <- 0
+            }
+            catch <- catch[1:which(midLengths == pg),]
+            catch[which(midLengths == pg),] <-
+                catch[which(midLengths == pg),] + addplus
         }
-      }
+    }
 
 
-        ## combine results
-        if(is.vector(catch)){
-            catches <- as.vector(catch)
-        }else catches <- as.matrix(catch)
+    ## combine results
+    if(is.vector(catch)){
+        catches <- as.vector(catch)
+    }else catches <- as.matrix(catch)
 
     res <- list()
     if("species" %in% names(lfq)) res$species <- lfq$species
@@ -450,18 +451,18 @@ lfqModify <- function(lfq, par = NULL,
     res$dates = dates
     res$midLengths = midLengths
     res$catch = catches
-    if("comment" %in% names(lfq)) res$comment <- lfq$comment 
+    if("comment" %in% names(lfq)) res$comment <- lfq$comment
 
     ## add growth parameter if known
     if("par" %in% names(lfq)){
-        if(class(lfq$par) == "list"){
+        if(inherits(lfq$par,"list")){
             res$par <- lfq$par
         }else{
             res$par <- as.list(lfq$par)
         }
     }
     if(!is.null(par)){
-        if(class(par) == "list"){
+        if(inherits(par,"list")){
             res$par <- par
         }else{
             res$par <- as.list(par)
@@ -473,7 +474,7 @@ lfqModify <- function(lfq, par = NULL,
     tmpList <- lfq[which(names(lfq) %in% idx)]
     res <- c(res, tmpList)
 
-    if(class(res) != "lfq"){
+    if(!inherits(res,"lfq")){
         class(res) <- "lfq"
     }
     ## if(!is.na(bin_size)){class(res) <- "lfq"}
